free_fonts: a free family of scalable outline fonts
===================================================

Description
-----------

This dummy package represents the GNU free fonts: a free family of scalable
outline fonts, suitable for general use on computers and for desktop
publishing. It is Unicode-encoded for compatibility with all modern operating
systems.

We do not have an SPKG for it. The purpose of this dummy package is to
associate system package lists with it.

License
-------

GNU General Public License GPLv3+

Upstream Contact
----------------

https://www.gnu.org/software/freefont/
